@@ -1,7 +1,7 @@
 #! /usr/bin/env python
 
+ver = "0.10.25.10.35"
 """
-ver 2010 09 13 09
 autor Bartlomiej Ceglik
 e-mail yoyoek[no spam]wp.pl
 """
@@ -72,13 +72,15 @@ def Info(str):
 
 
 import gtk
+import gobject
 import pygtk
 import gtk.glade
 import glib
 import hildon
 import os
 import httplib
-
+import getopt
+import sys
 
 try:
     from icalendar import Calendar, Event
@@ -100,12 +102,12 @@ def Read_ical_from_web( host, file ):
 
     try:
         conn = httplib.HTTPConnection( host )
+        conn.request("GET", file)
     except:
         done_ok = done_ok + "\n- "+host+" no route to host"
+        print "Read_ical_from_web - not correct"
         return ''
 
-    conn.request("GET", file)
-
     r1 = conn.getresponse()
     if r1.reason <> 'OK':
         print "connection error result\n-----------------------"
@@ -116,6 +118,22 @@ def Read_ical_from_web( host, file ):
     print 'feathing data from http ok :)'
     return r1.read()
 
+def Read_ical_from_file ( fp ):
+    tr = ''
+    print "read file %s" % fp
+    try:
+        f = open(fp,'r')
+        while f:
+            line = f.readline()
+            if line:
+                tr+= line
+            else:
+                break
+        print "read file %s DONE" % fp
+        return tr
+    except:
+        print "read file %s ERROR " % fp
+        return ''
 
 
 def list_join( list, glut ):
@@ -202,26 +220,66 @@ def Call_featch_val( item, val_name ):
 
 
 
-def Run_import():
+def Run_import( dialog = '' ):
+    
+    if dialog == '':
+        print "--------- no gui"
+    
     os.system("dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:\"py web call auto import start it's work...\"")
     global done_ok
 
+    cal_nr = 0;
     for ical in lista_of_icals:
+        cal_nr = cal_nr+1
 
-        subt_host = ical[0].split('/')
-        if len(subt_host) > 0:
-            ical[0] = subt_host[0]
-            ical.append(ical[1])
-            ical[1] = ''
-            for i in range(1, len(subt_host)):
-                 ical[1] = ical[1]+'/'+subt_host[i]
+        work_type = 'internet'
+        print "--------------- DETECT WORK TYPE ------------------------"
+        work_path = ical[0]
+        if work_path[:1] == '/':
+            print 'local work [%s]' % work_path
+            work_type = 'local'
+            ical[0] = work_path
+        elif work_path[:7] == 'http://':
+            ical[0] = work_path[7:]
+            print '1 internet work [%s] => [%s]' % (work_path, ical[0] )
+        elif work_path[:4] == 'www.':
+            ical[0] = work_path[4:]
+            print '2 internet work [%s] => [%s]' % (work_path, ical[0] )
         else:
-            ical.append(ical[1])
-            ical[1] = '/'
+            print '3 internet work [%s] ' % (ical[0] )
+        print "--------------- DETECT WORK TYPE ------------------------"
 
-        print "[Start ical iter]    [start]    ["+ical[0]+"] ["+ical[1]+"]"
 
-        ical_str = Read_ical_from_web( ical[0], ical[1]  )
+        if work_type == 'internet':
+            
+            subt_host = ical[0].split('/')
+            if len(subt_host) > 0:
+                ical[0] = subt_host[0]
+                ical.append(ical[1])
+                ical[1] = ''
+                for i in range(1, len(subt_host)):
+                     ical[1] = ical[1]+'/'+subt_host[i]
+            else:
+                ical.append(ical[1])
+                ical[1] = '/'
+    
+            print "[Start ical iter]    [start]    ["+ical[0]+"] ["+ical[1]+"]"
+    
+            s = "[%i/%i]working on %s"% (cal_nr, len(lista_of_icals),ical[0])
+            os.system("dbus-send --type=method_call --dest=org.freedesktop.Notifications "+
+                      "/org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint "+
+                      "string:\"%s\""% s)
+            
+            ical_str = Read_ical_from_web( ical[0], ical[1]  )
+        else:
+            host = ical[1]
+            offset = ical[0]
+            ical_str = Read_ical_from_file( ical[0] )
+            ical.append(ical[1]) 
+            print "local file len [%i]" % len( ical_str )
+            
+            
+            
         #ical_str = open('rcspot_calendar.ics','rb').read()
         if ical_str<> '':
             print "[Start ical iter]    [len]   ["+str(len(ical_str))+"]"
@@ -246,6 +304,7 @@ def Run_import():
 
             print "[Start ical iter]    [ical name] ["+cal_name+"]"
 
+
             print "[Start ical iter]    [sql try connect]"
             s_con = sqlite3.connect( sql_file )
             cal_id = Sql_query_select_one_value(s_con, 'CalendarId', 'Calendars', 'Name LIKE \''+cal_name+'\'')
@@ -287,7 +346,7 @@ def Run_import():
                     if modDate < 0:
                         modeDate = 0
 
-                print "entry(%s) mod(%s)" % ( entryDate, modDate )
+                #print "entry(%s) mod(%s)" % ( entryDate, modDate )
 
                 ev_ta.append(
                              [cal_id,        '1',                '-1',   tStart,         tEnd,        e['summary'],      location,           desc,               '-1',       '0',        '-1',   '0',    str(entryDate),     str(modDate),        ':UTC', '0']
@@ -303,7 +362,7 @@ def Run_import():
 
             print "[Start ical iter]    [sql try disconnect]"
             s_con.close()
-            done_ok = done_ok+"\n- ["+ical[0]+"] events:["+str(count_total)+"]    "+cal_name
+            done_ok = done_ok+"\n- ["+ical[0]+"] "+cal_name+"\n\tevents:["+str(count_total)+"]"
 
 
 
@@ -313,21 +372,35 @@ def Run_import():
         print "[Start ical iter]    [end]    ["+ical[0]+"]"
 
 
-    if error == 0:
+    if error == 0 and dialog <> '':
         Info( done_ok )
     print "[done oK] "+done_ok
 
+    if dialog == '':
+        os.system("dbus-send --type=method_call --dest=org.freedesktop.Notifications "+
+                      "/org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint "+
+                      "string:\"%s\""% done_ok)
+        sys.exit(2)
+    else:
+        dialog.destroy()
 
 
 class Start_dialog(hildon.Program):
+    
     dialog = gtk.Dialog()
     selected_item = -1
 
 
     def ev_import(self, widget=None ):
         self.iter = -1
-        self.dialog.destroy()
-        Run_import()
+        self.bt_config.hide()
+        self.bt_import.hide()
+        self.label_status.hide()
+        self.label_status.set_text("working...")
+        self.label_status.show()
+        Run_import( self.dialog )
+
+
 
     def ev_select_ok(self, widget, del_bt):
         global lista_of_icals
@@ -364,6 +437,12 @@ class Start_dialog(hildon.Program):
         self.bt_del = self.g.get_widget("button_del")
 
 
+
+        self.label1 = self.g.get_widget("label1")
+        self.label1.set_text("""Address: (for local strat from / )""")
+        self.label3 = self.g.get_widget("label3")
+        self.label3.set_text('')
+
         self.entry_addres = self.g.get_widget("entry_adres")
         self.entry_addres.set_text(adres)
 
@@ -449,9 +528,11 @@ class Start_dialog(hildon.Program):
 
 
     def timeOut_for_no_action(self):
+        global ver
         print "iter %i" % self.iter
+
         if self.iter > 0:
-            self.label_status.set_text( ("auto import in %i sec..." % self.iter) )
+            self.label_status.set_text( ("auto import in %i sec...\nver: %s" % (self.iter,ver)) )
             self.iter = self.iter -1
             glib.timeout_add( 1000, self.timeOut_for_no_action )
         elif self.iter == 0:
@@ -460,6 +541,7 @@ class Start_dialog(hildon.Program):
 
     def dialog_main(self, widget=None):
         global lista_of_icals
+        global ver
 
         self.iter = 15
         self.dialog.destroy()
@@ -484,7 +566,7 @@ class Start_dialog(hildon.Program):
         if len( lista_of_icals )>0:
             self.timeOut_for_no_action()
         else:
-            self.label_status.set_text("No webcal's set. Add some, click Preferences.")
+            self.label_status.set_text("No webcal's set. Add some, click Preferences.\n ver: %s" % ver)
             self.bt_import.hide()
 
         self.dialog.run()
@@ -495,9 +577,30 @@ class Start_dialog(hildon.Program):
         self.dialog_main()
 
 
+gui = 1
 
 if __name__ == "__main__":
+    msg = """ pywebcalai """+ver+"""
+    [no args]  you can star in with no args for gui mode
+    [cmd]      run in back ground no gui, run, do import and close
+""" 
+    args = getopt.getopt(sys.argv[1:], "h", ["help", "cmd"])
+    for a in args:
+        try:
+            if a[0] == "h" or a[0] == "-h" or a[0] == "--help":
+                print msg
+                sys.exit(2)
+            elif a[0] == "cmd":
+                gui = 0
+                print 'run back ground'                
+        except:
+            print ''
+    
+    
     conf_read()
-    Start_dialog()
+    if gui == 0:
+        Run_import()
+    else:
+        Start_dialog()
     print "si ja :)"
 
